import { Body, Controller, Post } from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { Public } from 'src/core/guards';
import { TransactionDto } from './dto/booking-order.dto';
import { TransactionEntity } from 'src/modules/transaction/transaction/domain/entities/transaction.entity';
import { TransactionDataService } from 'src/modules/transaction/transaction/data/services/transaction-data.service';
import { TABLE_NAME } from 'src/core/strings/constants/table.constants';
import { TransactionType } from 'src/modules/transaction/transaction/constants';
import { MidtransService } from 'src/modules/configuration/midtrans/data/services/midtrans.service';
import { CreateBookingManager } from '../domain/usecases/managers/create-booking.manager';

@ApiTags('Booking Order')
@Controller('v1/booking')
@Public(true)
export class BookingOrderController {
  constructor(
    private createBooking: CreateBookingManager,
    private serviceData: TransactionDataService,
    private midtransService: MidtransService,
  ) {}

  @Post()
  async create(@Body() data: TransactionDto): Promise<TransactionEntity> {
    const payload: Partial<TransactionEntity> = data;
    payload.type = TransactionType.ONLINE;

    this.createBooking.setData(payload as any);
    this.createBooking.setService(
      this.serviceData,
      TABLE_NAME.TRANSACTION,
      this.midtransService,
    );
    await this.createBooking.execute();
    return this.createBooking.getResult();
  }
}
